

def print_input(my_input: str):
    """This simply prints a useless sentence and the given input.

    Args:
        my_input (str): input to print
    """
    print(f'The this prints out the input: {my_input}')
